@@ -1074,3 +1074,68 @@ def ddr_control_file(control_file, delay):
                     time.sleep(delay)
         else:
             return
+            
+def ddr_show_parameter(device, access_type, genie_parser_name, show_template, pcount, par1, par2, par3, dict_name, debug_flag=False):
+        """
+            This function executes a show command to read and return a dictionary of show command results
+                * Execute show command using python "cli" 
+                * Substitute parameters in the show command if required
+                * Return the show command parameters in the dict_name specified
+
+            :param device: Device information and credentials for running show command
+            :param access_type: 'cli' to use the Python cli package in the guestshell
+            :param genie_parser_name: genie parser to use to process show command
+            :param show_template: show command to execute with optional parameters identified by {0}, {1}, {2}
+            :param pcount: Number of parameters to substitute in the show_command 0 to 3
+            :param parx: Values for parmeters 1, 2 and 3
+            :param parameter: The parameter (dictionary key name) to use as the test value
+            :param dict_name: Name of dictionary containing the returned data
+            :param debug_flag: True to enable debug output for this call, False no debug output (default)
+        
+        Usage::
+
+              ddr_show_parameter_all(device, 'cli', 'ShowInterface', 'show interface {0}', 1, 'mgmt0', 'none', 'none', 'GigabitEthernet0/0', debug_flag=True)
+
+            :raises none:
+
+        """
+        #######################################################################
+        #
+        # Generate the show command with parameters
+        #
+        #######################################################################
+        try:
+          cmdline = str(show_template)
+        #
+        # substitute parameters in command string if included in call
+        #
+          if int(pcount) == 0:
+            command = str(cmdline)
+          else:
+            if int(pcount) == 1:
+              command = str(show_template).format(str(par1))
+            elif int(pcount) == 2:
+              command = str(show_template).format(str(par1), str(par2))
+            elif int(pcount) == 3:
+              command = str(show_template).format(str(par1), str(par2), str(par3))
+        #
+        # If access-type is cli use the Python CLI package to run command
+        #
+          if str(access_type) == 'cli':
+            response = cli.cli(command)
+            debug_msg(debug_flag, f" ddr_show_parameter_all: cli python response: {str(response)}")
+
+          else:
+            error_msg(f"ddr_show_parameter_all Exception: only cli device access option currently supported")
+            raise
+    #
+    # parse the response to get the test leaf value
+    #
+          parser = genie_str_to_class(genie_parser_name)
+          dictionary = parser.cli(output=response)
+          debug_msg(debug_flag, f"ddr_show_parameter_all: parser dictionary: {str(dictionary)}")
+          return dictionary
+
+        except Exception as e:
+          error_msg(f"ddr_show_parameter_all Exception: {str(e)}")
+          raise
